@@ -1,6 +1,6 @@
 from enum import Enum
 
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
 class ContactMethodType(Enum):
