@@ -80,7 +80,7 @@ class Table(QuickRestoObject):
                  minCapacity: int = None, maxCapacity: int = None, reservable: bool = None, shape: str = None,
                  title: str = None, x: int = None, y: int = None,
                  **kwargs):
-        class_name = "ru.edgex.quickresto.modules.front.tablemanagement.Table"
+        class_name = "ru.edgex.quickresto.modules.front.tablemanagement.table.Table"
 
         super().__init__(class_name=class_name, **kwargs)
         self._angle: int = angle
