@@ -1,3 +1,4 @@
+from quick_resto_API.quick_resto_objects.modules.personnel.user import User
 from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
@@ -7,7 +8,7 @@ class Employee(QuickRestoObject):
         return self._system_employee
 
     @property
-    def user(self) -> dict:
+    def user(self) -> User:
         return self._user
 
     @property
@@ -37,7 +38,12 @@ class Employee(QuickRestoObject):
         super().__init__(class_name=class_name, **kwargs)
 
         self._system_employee: str = systemEmployee
-        self._user: dict = user
+
+        if user is not None:
+            self._user = User(**user)
+        else:
+            self._user = None
+
         self._first_name: str = firstName
         self._last_name: str = lastName
         self._blocked: bool = blocked
